==> prokyon3_0.9.2.orig.tar.gz: prokyon3-0.9.2/src/job_disconnectfromdatabase.cpp <==
/***************************************************************************
                job_disconnectfromdatabase.cpp  -  description
                             -------------------
    begin                : Fri May 4 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "job_disconnectfromdatabase.h"

#include "jobmanager.h"
#include "database.h"
#include "datadispatcher.h"

Job_DisconnectFromDatabase::Job_DisconnectFromDatabase() {}

void Job_DisconnectFromDatabase::run()
{
  database->lock();
  app->lock();

  database->disconnect();

  datadispatcher->eventLostConnection();

  app->unlock();
  database->unlock();
  
  jobman->lock();
  jobman->jobDone(this);
  jobman->unlock();
  exit();
}

Job_DisconnectFromDatabase::~Job_DisconnectFromDatabase() {}

==> prokyon3_0.9.4.orig.tar.gz: prokyon3-0.9.4/src/job_disconnectfromdatabase.cpp <==
/***************************************************************************
                job_disconnectfromdatabase.cpp  -  description
                             -------------------
    begin                : Fri May 4 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "job_disconnectfromdatabase.h"

#include "jobmanager.h"
#include "database.h"
#include "datadispatcher.h"

#ifdef EMBEDDED 
  #include <mysql.h>
#endif

Job_DisconnectFromDatabase::Job_DisconnectFromDatabase() {}

void Job_DisconnectFromDatabase::run()
{

  if (verbose==8) qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );

#ifdef EMBEDDED 
  mysql_thread_init(); 
#endif
  database->lock();
  app->lock();

  database->disconnect();

  app->unlock();
  database->unlock();
  
  jobman->lock();
  jobman->jobDone(this);
  jobman->unlock();
#ifdef EMBEDDED 
  mysql_thread_end(); 
#endif

  if (verbose==8) qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );

  exit();
}

Job_DisconnectFromDatabase::~Job_DisconnectFromDatabase() {}
